import sys
# caution: path[0] is reserved for script path (or '' in REPL)

# Import all our tests:
from Testdeltatextsplitter import deltatextsplitter_printtest

# Next use pytest to run all of our tests. In order to get pytest to pick
# up on our tests, we have to make sure that the script name is test_*.py and
# each function needs to starts with test_*() as well. Inside such a function,
# we need to call on of our own tests using the assert-command native to python.
# It works best if we only use a single assert-command per test_*()-function.

# NOTE: Documentation can be found at:
# https://coverage.readthedocs.io/en/latest/cmd.html
# https://docs.pytest.org/en/7.1.x/getting-started.html
# https://www.sealights.io/agile-testing/test-metrics/python-code-coverage/
# And of course, the Code.sh script.

# NOTE: Add your tests here!
def test_deltatextsplitter_printtest(): assert deltatextsplitter_printtest()==True



# import modules and classes you want to be available for
# installation. Be sure to add them to the relevant child-inits as well
# and be sure to use relative imports as from this directory!
from .Source.deltatextsplitter import deltatextsplitter




"""
# import modules and classes you want to be available for
# installation. Be sure to add them to the mother-init as well
# and be sure to use reletive imports as from this directory!
"""

# Imports:
from .deltatextsplitter import deltatextsplitter



import sys
# caution: path[0] is reserved for script path (or '' in REPL)

# Imports from Source code:
sys.path.insert(1, '../../')
from Source.deltatextsplitter import deltatextsplitter

# Definition of unit tests:
def deltatextsplitter_printtest() -> bool:
    """
    # Unit test for the printclass-functionality of the deltatextsplitter-class:
    # Parameters: none; # Returns (bool): succes of the text.
    """
    
    # Generate the class:
    mydelta = deltatextsplitter()

    # Print the output:
    mydelta.printclass()
        
    # Define the answer:
    Answer = True

    # Return the answer:
    return Answer
    
# Definition of collection:    
def deltatextsplitter_tests() -> bool:
    """
    # Collection-function of unit-tests.
    # Parameters: none; # Returns (bool): succes of the text.
    """
    
    # Define answer:
    Answer = True
    
    # Call the tests:
    if (deltatextsplitter_printtest()==False):
        Answer=False
        print('\n==> deltatextsplitter_printtest() failed!\n')
    
    # Return answer:
    return Answer

if __name__ == '__main__':
    if deltatextsplitter_tests():
        print("Test Succeeded!")
    else:
        print("\n==> Test FAILED!!!\n")



"""
Module for the printclass-fucntion, a member function of the deltatextsplitter class.
"""

def printclass_deltatextsplitter(self):
    """
    Member function of the deltatextsplitter-class to
    print an overview of the content of the class.

    # Parameters: None (taken from the class)
    # Return: None (printed in the terminal)
    """

    print(" ==> NOTE: " + str(self.label))

    # Done.



from distutils.core import setup
setup(
  name = 'deltatextsplitter',                                                       # Name of the package
  packages = ['deltatextsplitter', 'deltatextsplitter.Source'],                     # Each folder to copy must be in here; first = same as package name.
  version = '0.0.1',                                                                # Speaks for itself, keep in sync with the textsplitter-class!
  license='MIT',                                                                    # Most commonly used licenses: https://help.github.com/articles/licensing-a-repository
  description = 'This packages can efficiently measure the text structure recognition capabilities ofn pdftextsplitter',
  author = 'Unit Data en Innovatie, Ministerie van Infrastructuur en Waterstaat, Netherlands',
  author_email = 'dataloket@minienw.nl',                                            # Contact email address
  url = 'https://gitlab.com/datainnovatielab/public/deltatextsplitter/dist/',       # Link to the repository.
  download_url = 'https://gitlab.com/datainnovatielab/public/deltatextsplitter/dist/',
  keywords = ['NLP', 'PDF', 'Text recognition', 'Structure recognition', 'ChatGPT'],
  install_requires=[                                                                # the list of dependencies: other packages that your package needs to function.
          'setuptools>=59.6.0',
          'wheel>=0.41.1',
          'build>=0.10.0',
          'numpy>=1.25.2',
          'pandas>=2.0.3',
          'pytest>=7.3.0,<=7.4.0',
          'coverage>=7.3.0',
          'pylint>=2.17.5',
          'pdftextsplitter>=1.2.5',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',                                              # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',                                              # The intended audience for the package
    'Topic :: Software Development :: Build Tools',                                 # Better to keep this as it is.
    'License :: OSI Approved :: MIT License',                                       # Should be the same as the previous license choice.
    'Programming Language :: Python :: 3.10',                                       # Specification of which python versions are supported.
  ],
)



"""
Main module for the deltatextsplitter-class
"""

# Import Python base-functionality:

# Import functionality from pdftextsplitter
from pdftextsplitter import textsplitter

# Import all the memberfunctions of this class or other classes we need;
# always use relative imports as from this directory:
from .printclass import printclass_deltatextsplitter

# Main class definition:
class deltatextsplitter:
    """
    This class is the mother-class of the deltatextsplitter-package. It handles
    the comparison of outputs from the pdftextsplitter-package against references.
    These references must be user-provided. The idea is that the user selects a
    certain number of reference-PDF documents (a testset) and provides
    references for those documents; meaning that the user specifies which
    structure elements are supposed to be found.

    The deltatextsplitter then compares these references against the actual
    output of pdftextsplitter and generates a clear KPI of the overall
    performance of pdftextsplitter in text structure recognition.
    """
    
    # ------------------------------------------------------------------------------------
    
    # Definition of the default-constructor:
    def __init__(self):

        # Class members:
        self.label = "deltatextsplitter"
        self.splitter = textsplitter()
        
    # Definition of class member functions:
    printclass = printclass_deltatextsplitter
